@@ -154,9 +154,8 @@ def __read_hubspot(settings: dict):
 ##################################
 
 
-def read_fb_ads(my_app_id, my_app_secret, my_access_token,
+def read_fb_ads(my_app_id, my_app_secret, my_access_token, start_date, end_date,
                 
-                date_preset = "last_7d",
                 
                 account_name = {'Numbers' : 'act_113103090066338',
                                 'Linkers' : 'act_203938767415072',
@@ -169,7 +168,7 @@ def read_fb_ads(my_app_id, my_app_secret, my_access_token,
     
     from askdata.integrations import facebook_api
     
-    fb_ads = facebook_api.get_fb_ads(my_app_id, my_app_secret, my_access_token, date_preset, account_name)
+    fb_ads = facebook_api.get_fb_ads(my_app_id, my_app_secret, my_access_token, start_date, end_date, account_name)
 
     return fb_ads
 
@@ -180,7 +179,7 @@ def read_fb_ads(my_app_id, my_app_secret, my_access_token,
 ################################
 
 
-def read_google_ads(n_range = 7, 
+def read_google_ads(start_date, end_date,
                    
                   admin_account = {'Be You': '291-824-5921'
                                  ,'Humable': '760-045-3647'
@@ -196,7 +195,7 @@ def read_google_ads(n_range = 7,
     
     from askdata.integrations import google_api
     
-    google_ads = google_api.get_google_ads(n_range, admin_account, yaml_file_path)
+    google_ads = google_api.get_google_ads(start_date, end_date, admin_account, yaml_file_path)
     
     return google_ads
     
@@ -211,12 +210,12 @@ def read_google_ads(n_range = 7,
 
 def read_aircall_calls(token, api_key, #mandatory
                       
-                      start_date = '2022-01-01', end_date = '2022-01-07' #optional
+                      start = 7, end = 0 #optional
                      ):
     
     from askdata.integrations import aircall_api
     
-    aircall_calls = aircall_api.get_aircall_calls(token, api_key, start_date, end_date)
+    aircall_calls = aircall_api.get_aircall_calls(token, api_key, start, end)
     
     return aircall_calls
     
