@@ -16,13 +16,12 @@ import _locale
 
 
 """
-ALL INPUTS ARE OPTIONAL
+MANDATORY INPUT:
 
----- the function can be run as get_google_ads() if no parameters are setted before.----
+start_date, end_date as string "yyyy-mm-dd"
 
+OPTIONAL INPUTS: 
 
-- n_range: Define the report date range, last n days including today. 
-           Optional, Default last 7 days
 
 - admin_account: dictionary with name and id. 
                 Optional, by default it gets 'Be You', 'Humable','Linkers','Miss Tariffa','Miss Tariffa Agency','Numbers','Wearefiber'
@@ -34,7 +33,7 @@ ALL INPUTS ARE OPTIONAL
 """
 
 
-def get_google_ads(n_range = 7, 
+def get_google_ads(start_date, end_date,
                    
                   admin_account = {'Be You': '291-824-5921'
                                  ,'Humable': '760-045-3647'
@@ -50,9 +49,7 @@ def get_google_ads(n_range = 7,
 
     _locale._getdefaultlocale = (lambda *args: ['en_US', 'UTF-8'])
 
-    start=datetime.today().date().isoformat().replace("-", "")
-    end=datetime.now() + timedelta(days= - n_range)
-    end= end.date().isoformat().replace("-","")
+    
 
 
 
@@ -116,9 +113,8 @@ def get_google_ads(n_range = 7,
 
 
     for k, v in admin_account.items():
-        # df=run_campaign_performance_report(k, v,start, end)
 
-        df=run_Hour0fDay_kip_report(k, v,start, end)
+        df=run_Hour0fDay_kip_report(k, v,start_date, end_date)
 
         google_ads = pd.concat([google_ads, df])
         
